import { h } from 'preact'
import { useEffect, useRef, useState } from 'preact/hooks'
import { bool, string } from 'prop-types'

import { H1, H2 } from '../Text'
import {
  Wrapper,
  PositionedLogo as Logo,
  TaglineContainer,
  Title,
  Content,
  Fade,
} from './styles'
import translations from '../../data/strings'
import { colours } from '../../assets/theme'
import Loader from '../Loader'
import { useTimeout } from '../../hooks/timerHooks'

const InfoLayout = ({ title, children, loading }) => {
  return (
    <Wrapper>
      <Fade>
        <Logo active colour={colours.midnightDarker} />
      </Fade>
      <Content>
        {loading ? (
          <div>
            <Loader />
          </div>
        ) : (
          <Title>{title}</Title>
        )}
        {children}
      </Content>

      <TaglineContainer>
        {translations &&
          translations.en.underscoreTagline.map(line => (
            <H1 align="right" key={line}>
              {line}
            </H1>
          ))}
      </TaglineContainer>
    </Wrapper>
  )
}

InfoLayout.propTypes = {
  title: string,
  loading: bool,
}

export default InfoLayout
